==> percona-xtrabackup-80_8.0.13.orig.tar.gz: percona-xtrabackup-8.0.13/storage/ndb/src/common/debugger/signaldata/FsAppendReq.cpp <==
/*
   Copyright (C) 2003, 2005, 2006 MySQL AB
    Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/



#include <signaldata/FsAppendReq.hpp>

bool
printFSAPPENDREQ(FILE * output, const Uint32 * theData, 
		 Uint32 len, Uint16 receiverBlockNo){
  
  bool ret = true;
  
  const FsAppendReq * const sig = (FsAppendReq *) theData;
  
  fprintf(output, " FilePointer: %d\n", sig->filePointer);
  fprintf(output, " UserReference: H\'%.8x, UserPointer: H\'%.8x\n", 
	  sig->userReference, sig->userPointer);
  
  fprintf(output, " varIndex: %d offset: %d size: %d\n",
	  sig->varIndex,
	  sig->offset,
	  sig->size);
  return ret;
}

==> percona-xtrabackup-80_8.0.30-23.orig.tar.gz: percona-xtrabackup-8.0.30-23/storage/ndb/src/common/debugger/signaldata/FsAppendReq.cpp <==
/*
   Copyright (c) 2003, 2022, Oracle and/or its affiliates.
    Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include <signaldata/FsAppendReq.hpp>

bool printFSAPPENDREQ(FILE *output,
                      const Uint32 *theData,
                      Uint32 len,
                      Uint16 /*receiverBlockNo*/)
{
  if (len < FsAppendReq::SignalLength)
  {
    assert(false);
    return false;
  }

  bool ret = true;

  const FsAppendReq *const sig = (const FsAppendReq *)theData;

  fprintf(output, " FilePointer: %d\n", sig->filePointer);
  fprintf(output, " UserReference: H\'%.8x, UserPointer: H\'%.8x\n", 
	  sig->userReference, sig->userPointer);
  
  fprintf(output, " varIndex: %d offset: %d size: %d\n",
	  sig->varIndex,
	  sig->offset,
	  sig->size);
  return ret;
}
